Uses of Class
io.microsphere.spring.context.annotation.ExposingClassPathBeanDefinitionScanner
Packages that use ExposingClassPathBeanDefinitionScanner
-
Uses of ExposingClassPathBeanDefinitionScanner in io.microsphere.spring.beans.factory.annotation
Methods in io.microsphere.spring.beans.factory.annotation with parameters of type ExposingClassPathBeanDefinitionScannerModifier and TypeMethodDescriptionprotected abstract voidAnnotationBeanDefinitionRegistryPostProcessor.registerExtendedBeanDefinitions(ExposingClassPathBeanDefinitionScanner scanner, Map<String, org.springframework.beans.factory.annotation.AnnotatedBeanDefinition> mainBeanDefinitions, String[] basePackages) Register the extendedBeanDefinitionsAnnotationBeanDefinitionRegistryPostProcessor.registerMainBeanDefinitions(ExposingClassPathBeanDefinitionScanner scanner, String[] basePackages) Scan and register the mainBeanDefinitionsthat were annotated bythe supported annotation types, and then return theMapwith bean name plus aliases if present and mainAnnotatedBeanDefinitions.