Interface OverrideAnnotationAttributesStrategy
- All Known Implementing Classes:
ConfigurationPropertyOverrideAnnotationAttributesStrategy
public interface OverrideAnnotationAttributesStrategy
The strategy interface for overriding annotation attributes.
The instance of this interface is similar to the Spring bean, which will be
initialized and not
be registered as a Spring bean into the Spring BeanFactory.
- Since:
- 1.0.0
- Author:
- Mercy
- See Also:
-
Method Summary
Modifier and TypeMethodDescriptionorg.springframework.core.annotation.AnnotationAttributesoverride(org.springframework.core.annotation.AnnotationAttributes originalAttributes, Class<? extends Annotation> annotationType, org.springframework.core.type.AnnotationMetadata annotationMetadata) Override annotation attributes
-
Method Details
-
override
@Nullable org.springframework.core.annotation.AnnotationAttributes override(@Nonnull org.springframework.core.annotation.AnnotationAttributes originalAttributes, @Nonnull Class<? extends Annotation> annotationType, @Nonnull org.springframework.core.type.AnnotationMetadata annotationMetadata) Override annotation attributes- Parameters:
originalAttributes- the original annotation attributesannotationType- the annotation typeannotationMetadata- the annotation metadata- Returns:
nullif not override, or the overridden annotation attributes
-